==> hs-gtkglext-0.12.0_1.tbz: lib/ghc-7.0.3/cabal/gtkglext-0.12.0/register.sh <==
#!/bin/sh
echo 'name: gtkglext
version: 0.12.0
id: gtkglext-0.12.0-1c38975c59022e26bdd311266469e142

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: GtkGLExt provides the GDK objects to support OpenGL rendering in GTK+,
             and GtkWidget API add-ons to make GTK+ widgets OpenGL-capable.
category: Graphics
author: Duncan Coutts
exposed: True
exposed-modules: Graphics.UI.Gtk.OpenGL
                 Graphics.UI.Gtk.OpenGL.Config Graphics.UI.Gtk.OpenGL.Context
                 Graphics.UI.Gtk.OpenGL.Drawable Graphics.UI.Gtk.OpenGL.DrawingArea
                 Graphics.UI.Gtk.OpenGL.General Graphics.UI.Gtk.OpenGL.Pixmap
                 Graphics.UI.Gtk.OpenGL.Window
hidden-modules: Graphics.UI.Gtk.OpenGL.Types
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/gtkglext-0.12.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/gtkglext-0.12.0
              /usr/local/lib
hs-libraries: HSgtkglext-0.12.0
extra-libraries: gtkglext-x11-1.0 gdkglext-x11-1.0 GLU GL
                 gtk-x11-2.0 pangox-1.0 gdk-x11-2.0 atk-1.0 pangocairo-1.0 Xext
                 Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage
                 gdk_pixbuf-2.0 pangoft2-1.0 gio-2.0 Xfixes cairo X11 pango-1.0 m
                 freetype fontconfig gobject-2.0 gmodule-2.0 gthread-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gtkglext-1.0
              /usr/local/lib/gtkglext-1.0/include /usr/local/include/gtk-2.0
              /usr/local/lib/gtk-2.0/include /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/cairo /usr/local/include/glib-2.0
              /usr/local/include/pixman-1 /usr/local/include/freetype2
              /usr/local/include/libpng /usr/local/include/atk-1.0
includes:
depends: array-0.3.0.2-ecfce597e0f16c4cd1df0e1d22fd66d4
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         cairo-0.12.0-0298aadd5c50de52030d550500daacb0
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         glib-0.12.0-8ee4233c74a76a3c53a9d5252cb0d3ba
         gtk-0.12.0-83fca16a6800db6e01669a59440f2b9f
         haskell98-1.1.0.1-d297a29bdc63fd1be05662f1882b09e7
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
         pango-0.12.0-f434ae0cbcfb06326a9578191b9d68f9
hugs-options:
cc-options:
ld-options: -R/usr/local/lib "-Wl,--export-dynamic" -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/gtkglext-0.12.0/html/gtkglext.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/gtkglext-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gtkglext-0.12.1.tbz: lib/ghc-7.0.4/cabal/gtkglext-0.12.1/register.sh <==
#!/bin/sh
echo 'name: gtkglext
version: 0.12.1
id: gtkglext-0.12.1-5c135ff60a41a207273f513196f8c748

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: GtkGLExt provides the GDK objects to support OpenGL rendering in GTK+,
             and GtkWidget API add-ons to make GTK+ widgets OpenGL-capable.
category: Graphics
author: Duncan Coutts
exposed: True
exposed-modules: Graphics.UI.Gtk.OpenGL
                 Graphics.UI.Gtk.OpenGL.Config Graphics.UI.Gtk.OpenGL.Context
                 Graphics.UI.Gtk.OpenGL.Drawable Graphics.UI.Gtk.OpenGL.DrawingArea
                 Graphics.UI.Gtk.OpenGL.General Graphics.UI.Gtk.OpenGL.Pixmap
                 Graphics.UI.Gtk.OpenGL.Window
hidden-modules: Graphics.UI.Gtk.OpenGL.Types
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/gtkglext-0.12.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/gtkglext-0.12.1
              /usr/local/lib
hs-libraries: HSgtkglext-0.12.1
extra-libraries: gtkglext-x11-1.0 gdkglext-x11-1.0 GLU GL
                 gtk-x11-2.0 pangox-1.0 gdk-x11-2.0 atk-1.0 pangocairo-1.0 Xext
                 Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage
                 gdk_pixbuf-2.0 pangoft2-1.0 gio-2.0 Xfixes cairo X11 pango-1.0 m
                 freetype fontconfig gobject-2.0 gmodule-2.0 gthread-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/gtkglext-1.0
              /usr/local/lib/gtkglext-1.0/include /usr/local/include/gtk-2.0
              /usr/local/lib/gtk-2.0/include /usr/local/include/pango-1.0
              /usr/local/include/gio-unix-2.0/ /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/cairo /usr/local/include/glib-2.0
              /usr/local/include/pixman-1 /usr/local/include/freetype2
              /usr/local/include/libpng /usr/local/include/atk-1.0
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         glib-0.12.2-14d626c7282f5f31da9b4a299a29106c
         gtk-0.12.2-eb6577e503c9105a0b596523a2dbc206
         pango-0.12.2-940a57a1d080812b6ad7997572bc4304
hugs-options:
cc-options:
ld-options: -R/usr/local/lib "-Wl,--export-dynamic" -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/gtkglext-0.12.1/html/gtkglext.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/gtkglext-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
